@@ -1,10 +1,14 @@
+# vim: ts=2 sw=2 expandtab
 use strict;
 
 use lib qw(./mylib ../mylib);
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-sub POE::Kernel::TRACE_DEFAULT  () { 1 }
-sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
+
+BEGIN {
+  package POE::Kernel;
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
+}
 
 use POE;
 use POE::Pipe::TwoWay;
@@ -35,7 +39,7 @@ unless (-f "run_network_tests") {
   plan skip_all => "Network access (and permission) required to run this test";
 }
 
-plan tests => 192;
+plan tests => 132;
 
 ### Factored out common tests
 
@@ -44,7 +48,7 @@ sub verify_handle_structure {
   my ($name, $handle_info) = @_;
 
   my $expected_handles = {
-    $poe_kernel => do {
+    $poe_kernel->ID => do {
       my %h;
       for (@$handle_info) {
         my ($fh, $modes) = @$_;
@@ -54,7 +58,7 @@ sub verify_handle_structure {
         my $ex = $modes =~ /x/ ? 1 : 0;
         die "woops: $modes" if $modes =~ /[^rwx]/;
 
-        $h{$fh} = [
+        $h{fileno($fh)} = [
           $fh,                # SH_HANDLE
           $rd + $wr + $ex,    # SH_REFCOUNT
           [                   # SH_MODECOUNT
@@ -84,8 +88,8 @@ sub verify_handle_sessions {
     my ($event) = @_;
     return +{} unless defined $event;
     return +{
-      $poe_kernel => {
-        $fh => [
+      $poe_kernel->ID => {
+        fileno($fh) => [
           $fh,           # HSS_HANDLE
           $poe_kernel,   # HSS_SESSION
           $event,        # HSS_STATE
@@ -137,15 +141,6 @@ sub verify_handle_refcounts {
     is( $wr, $expected_wr, "$name: fd write refcount" );
     is( $ex, $expected_ex, "$name: fd expedite refcount" );
   }
-
-  {
-    my ($rd, $wr, $ex) = $poe_kernel->_data_handle_fno_evcounts(
-      fileno($fh)
-    );
-    ok( $rd == 0, "$name: event read refcount" );
-    ok( $wr == 0, "$name: event write refcount" );
-    ok( $ex == 0, "$name: event expedite refcount" );
-  }
 }
 
 # 6 subtests
@@ -166,22 +161,19 @@ sub verify_handle_state {
   my $wr = $parse_str->($wr_str);
   my $ex = $parse_str->($ex_str);
 
-  my ($r_act, $r_req, $w_act, $w_req, $e_act, $e_req) =
+  my ($r_act, $w_act, $e_act) =
     $poe_kernel->_data_handle_fno_states(fileno($fh));
 
   ok( $r_act == $$rd[0], "$name: read actual state" );
-  ok( $r_req == $$rd[1], "$name: read requested state" );
   ok( $w_act == $$wr[0], "$name: write actual state" );
-  ok( $w_req == $$wr[1], "$name: write requested state" );
   ok( $e_act == $$ex[0], "$name: expedite actual state" );
-  ok( $e_req == $$ex[1], "$name: expedite requested state" );
 }
 
 ### Tests
 
 # Get a baseline reference count for the session, to use as
 # comparison.
-my $base_refcount = $poe_kernel->_data_ses_refcount($poe_kernel);
+my $base_refcount = $poe_kernel->_data_ses_refcount($poe_kernel->ID);
 
 # We need some file handles to work with.
 my ($a_read, $a_write, $b_read, $b_write) = POE::Pipe::TwoWay->new("inet");
@@ -192,7 +184,7 @@ $poe_kernel->_data_handle_add($a_read, MODE_RD, $poe_kernel, "event-rd", []);
 
 # Verify reference counts.
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 1,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 1,
   "first read add: session reference count"
 );
 verify_handle_refcounts(
@@ -223,7 +215,7 @@ $poe_kernel->_data_handle_add($b_read, MODE_RD, $poe_kernel, "event-rd", []);
 # Verify reference counts.
 
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 2,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 2,
   "second read add: session reference count"
 );
 
@@ -259,7 +251,7 @@ die "woops, we've assumed that write handles have same fileno as read handles"
   unless fileno($a_write) == fileno($a_read);
 
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 2,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 2,
   "third write add: session reference count"
 );
 
@@ -291,7 +283,7 @@ $poe_kernel->_data_handle_add($b_write, MODE_EX, $poe_kernel, "event-ex", []);
 # Verify reference counts.
 
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 2,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 2,
   "fourth expedite add: session reference count"
 );
 
@@ -387,16 +379,16 @@ ok(
 $poe_kernel->_data_handle_enqueue_ready(MODE_RD, fileno($a_read));
 $poe_kernel->_data_handle_enqueue_ready(MODE_WR, fileno($a_read));
 
-# Enqueuing ready events pauses the actual states of the filehandles,
-# but leaves them intact.
+# Events are dispatched right away, so the handles need not be paused.
 verify_handle_state(
   "dequeue one", $a_read,
-  "pr", "pr", "pp"
+  "rr", "rr", "pp"
 );
 
-# Base refcount increases by two for each enqueued event.
-ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 6,
+# Base refcount is not increased, because the event is actually
+# dispatched right away.
+is(
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID), $base_refcount + 2,
   "dequeue one: session reference count"
 );
 
@@ -406,7 +398,7 @@ $poe_kernel->_data_handle_pause($a_read, MODE_RD);
 
 verify_handle_state(
   "pause one", $a_read,
-  "pp", "pr", "pp"
+  "pp", "rr", "pp"
 );
 
 # Dispatch the event, and verify the session's status.  The sleep()
@@ -436,7 +428,7 @@ ok(
   "number of handles tracked"
 );
 ok(
-  $poe_kernel->_data_handle_count_ses($poe_kernel) == 2,
+  $poe_kernel->_data_handle_count_ses($poe_kernel->ID) == 2,
   "number of sessions tracking"
 );
 ok(
@@ -445,11 +437,11 @@ ok(
 );
 
 # Remove a filehandle and verify the structures.
-$poe_kernel->_data_handle_remove($a_read, MODE_RD, $poe_kernel);
+$poe_kernel->_data_handle_remove($a_read, MODE_RD, $poe_kernel->ID);
 
 # Verify reference counts.
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 2,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 2,
   "first remove: session reference count"
 );
 
@@ -475,11 +467,11 @@ verify_handle_structure(
 );
 
 # Remove a filehandle and verify the structures.
-$poe_kernel->_data_handle_remove($a_write, MODE_WR, $poe_kernel);
+$poe_kernel->_data_handle_remove($a_write, MODE_WR, $poe_kernel->ID);
 
 # Verify reference counts.
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 1,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 1,
   "second remove: session reference count"
 );
 ok(
@@ -489,9 +481,9 @@ ok(
 
 # Remove a nonexistent filehandle and verify the structures.  We just
 # make sure the reference count matches the previous one.
-$poe_kernel->_data_handle_remove(\*STDIN, MODE_RD, $poe_kernel);
+$poe_kernel->_data_handle_remove(\*STDIN, MODE_RD, $poe_kernel->ID);
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 1,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 1,
   "nonexistent remove: session reference count"
 );
 
@@ -524,14 +516,17 @@ ok(
       $poe_kernel->_data_handle_add($dup_fh, MODE_RD, $poe_kernel,
         "event-rd", []);
     };
-    ok($@ ne '', "failure when adding different handle but same FD");
+    TODO: {
+      local $TODO = "Rekeyed file watchers on descriptors for iThread safety";
+      ok($@ ne '', "failure when adding different handle but same FD");
+    };
   }
 
-  $poe_kernel->_data_handle_remove($fh, MODE_RD, $poe_kernel);
-  $poe_kernel->_data_handle_remove($fh, MODE_WR, $poe_kernel);
+  $poe_kernel->_data_handle_remove($fh, MODE_RD, $poe_kernel->ID);
+  $poe_kernel->_data_handle_remove($fh, MODE_WR, $poe_kernel->ID);
 
   ok(
-    $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 1,
+    $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 1,
     "regular file: session reference count"
   );
   ok(
@@ -562,11 +557,11 @@ SKIP: {
   verify_handle_structure("tied fh",
     [ [$fh => 'wx'], [$b_read => 'rx'] ]);
 
-  $poe_kernel->_data_handle_remove($fh, MODE_WR, $poe_kernel);
-  $poe_kernel->_data_handle_remove($fh, MODE_EX, $poe_kernel);
+  $poe_kernel->_data_handle_remove($fh, MODE_WR, $poe_kernel->ID);
+  $poe_kernel->_data_handle_remove($fh, MODE_EX, $poe_kernel->ID);
 
   ok(
-    $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount + 1,
+    $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount + 1,
     "tied fh: session reference count"
   );
   ok(
@@ -594,7 +589,7 @@ SKIP: {
 }
 
 # Remove all handles for the session.  And verify the structures.
-$poe_kernel->_data_handle_clear_session($poe_kernel);
+$poe_kernel->_data_handle_clear_session($poe_kernel->ID);
 ok(
   !$poe_kernel->_data_handle_is_good($b_write, MODE_EX),
   "final remove all: session reference count"
@@ -602,7 +597,7 @@ ok(
 
 # Check again that all handles are gone
 ok(
-  $poe_kernel->_data_ses_refcount($poe_kernel) == $base_refcount,
+  $poe_kernel->_data_ses_refcount($poe_kernel->ID) == $base_refcount,
   "session reference count is back to base count"
 );
 
